/*******************************************************************************
* File Name: Shift_Reg.h
* Version 2.0
*
* Description:
*  This header file contains definitions associated with the Shift Register
*  component.
*
* Note: none
*
********************************************************************************
* Copyright 2008-2010, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
********************************************************************************/


#ifndef CY_SHIFTREG_Shift_Reg_H
#define CY_SHIFTREG_Shift_Reg_H

#include "cytypes.h"
#include "cyfitter.h"


/***************************************
*   Conditional Compilation Parameters
***************************************/

#define Shift_Reg_FIFO_SIZE                (4u)
#define Shift_Reg_USE_INPUT_FIFO           (0u)
#define Shift_Reg_USE_OUTPUT_FIFO          (0u)
#define Shift_Reg_SR_SIZE                  (8u)


/***************************************
*     Data Struct Definitions
***************************************/

/* Sleep Mode API Support */

typedef struct _Shift_Reg_backupStruct
{    
    uint8 enableState;
    
    uint8 saveSrA0Reg;
    uint8 saveSrA1Reg;

    #if(CY_PSOC3_ES2 || CY_PSOC5_ES1) /* PSoC3 ES2 or early, PSoC5 ES1*/
        uint8 saveSrIntMask;
    #endif /*(CY_PSOC3_ES2 || CY_PSOC5_ES1)*/

} Shift_Reg_BACKUP_STRUCT;


/***************************************
*        Function Prototypes
***************************************/

void  Shift_Reg_Start(void);
void  Shift_Reg_Stop(void) ; 
void  Shift_Reg_Init(void) ;
void  Shift_Reg_Enable(void) ; 
void  Shift_Reg_RestoreConfig(void) ;
void  Shift_Reg_SaveConfig(void);
void  Shift_Reg_Sleep(void);
void  Shift_Reg_Wakeup(void) ; 
void  Shift_Reg_EnableInt(void) ;
void  Shift_Reg_DisableInt(void) ;
void  Shift_Reg_SetIntMode(uint8 interruptSource) ;
uint8 Shift_Reg_GetIntStatus(void) ;
void  Shift_Reg_WriteRegValue(uint8 shiftData) \
                    ;
uint8 Shift_Reg_ReadRegValue(void) ;
uint8    Shift_Reg_GetFIFOStatus(uint8 fifoId) ;

#if (Shift_Reg_USE_INPUT_FIFO == 1u)
    uint8 Shift_Reg_WriteData(uint8 shiftData)\
                    ;
#endif/*(Shift_Reg_USE_INPUT_FIFO == 1u)*/
#if (Shift_Reg_USE_OUTPUT_FIFO == 1u)
    uint8 Shift_Reg_ReadData(void) ;
#endif/*(Shift_Reg_USE_OUTPUT_FIFO == 1u)*/


/***************************************
*           API Constants
***************************************/

#define Shift_Reg_LOAD                     (0x01u)
#define Shift_Reg_STORE                    (0x02u)
#define Shift_Reg_RESET                    (0x04u)

#define Shift_Reg_IN_FIFO                  (0x01u)
#define Shift_Reg_OUT_FIFO                 (0x02u)

#define Shift_Reg_RET_FIFO_FULL            (0x00u)
#define Shift_Reg_RET_FIFO_NOT_EMPTY       (0x01u)
#define Shift_Reg_RET_FIFO_EMPTY           (0x02u)

#define Shift_Reg_RET_FIFO_NOT_DEFINED     (0xFEu)
#define Shift_Reg_RET_FIFO_BAD_PARAM       (0xFFu)

/***************************************
*    Enumerated Types and Parameters
***************************************/

#define Shift_Reg__LEFT 0
#define Shift_Reg__RIGHT 1



/***************************************
*    Initial Parameter Constants
***************************************/

#define Shift_Reg_SR_MASK                  (0xFFu)
#define Shift_Reg_INT_SRC                  (0u)
#define Shift_Reg_DIRECTION                (1u)


/***************************************
*             Registers
***************************************/

/* Shift Register control register */

#define Shift_Reg_SR_CONTROL_REG       (* (reg8 *) \
    Shift_Reg_bSR_AsyncCtl_CtrlReg__CONTROL_REG)
#define Shift_Reg_SR_CONTROL_PTR       (  (reg8 *) \
    Shift_Reg_bSR_AsyncCtl_CtrlReg__CONTROL_REG)

/* Obsolete control reg name*/
#define Shift_Reg_SR_CONTROL               Shift_Reg_SR_CONTROL_REG

/* Shift Regisster interupt status register */

#define Shift_Reg_SR_STATUS_REG            (* (reg8 *) Shift_Reg_bSR_StsReg__STATUS_REG)
#define Shift_Reg_SR_STATUS_PTR            (  (reg8 *) Shift_Reg_bSR_StsReg__STATUS_REG)
#define Shift_Reg_SR_STATUS_MASK_REG       (* (reg8 *) Shift_Reg_bSR_StsReg__MASK_REG)
#define Shift_Reg_SR_STATUS_MASK_PTR       (  (reg8 *) Shift_Reg_bSR_StsReg__MASK_REG)
#define Shift_Reg_SR_AUX_CONTROL_REG       (* (reg8 *) Shift_Reg_bSR_StsReg__STATUS_AUX_CTL_REG)
#define Shift_Reg_SR_AUX_CONTROL_PTR       (  (reg8 *) Shift_Reg_bSR_StsReg__STATUS_AUX_CTL_REG)

/* Obsolete names */
#define Shift_Reg_SR_STATUS                Shift_Reg_SR_STATUS_REG
#define Shift_Reg_SR_STATUS_MASK           Shift_Reg_SR_STATUS_MASK_REG
#define Shift_Reg_SR_AUX_CONTROL           Shift_Reg_SR_AUX_CONTROL_REG


#define Shift_Reg_IN_FIFO_VAL_LSB_PTR      ((reg8 *) \
    Shift_Reg_bSR_sC8_BShiftRegDp_u0__F0_REG )
#define Shift_Reg_SHIFT_REG_LSB_PTR        ((reg8 *) \
    Shift_Reg_bSR_sC8_BShiftRegDp_u0__A0_REG )
#define Shift_Reg_SHIFT_REG_VALUE_LSB_PTR  ((reg8 *) \
    Shift_Reg_bSR_sC8_BShiftRegDp_u0__A1_REG )
#define Shift_Reg_OUT_FIFO_VAL_LSB_PTR     ((reg8 *) \
    Shift_Reg_bSR_sC8_BShiftRegDp_u0__F1_REG )

/***************************************
*       Register Constants
***************************************/

#define Shift_Reg_INTERRUPTS_ENABLE        (0x10u)
#define Shift_Reg_LOAD_INT_EN              (0x01u)
#define Shift_Reg_STORE_INT_EN             (0x02u)
#define Shift_Reg_RESET_INT_EN             (0x04u)
#define Shift_Reg_CLK_EN                   (0x01u)

#define Shift_Reg_RESET_INT_EN_MASK        (0xFBu)
#define Shift_Reg_LOAD_INT_EN_MASK         (0xFEu)
#define Shift_Reg_STORE_INT_EN_MASK        (0xFDu)
#define Shift_Reg_INTS_EN_MASK             (0x07u)

#define Shift_Reg_OUT_FIFO_CLR_BIT         (0x02u)

#if (Shift_Reg_USE_INPUT_FIFO == 1u)

    #define Shift_Reg_IN_FIFO_MASK         (0x18u)

    #define Shift_Reg_IN_FIFO_FULL         (0x00u)
    #define Shift_Reg_IN_FIFO_EMPTY        (0x01u)
    #define Shift_Reg_IN_FIFO_NOT_EMPTY    (0x02u)
    
#endif/*(Shift_Reg_USE_INPUT_FIFO == 1u)*/

#define Shift_Reg_OUT_FIFO_MASK            (0x60u)

#define Shift_Reg_OUT_FIFO_EMPTY           (0x00u)
#define Shift_Reg_OUT_FIFO_FULL            (0x01u)
#define Shift_Reg_OUT_FIFO_NOT_EMPTY       (0x02u)
#define Shift_Reg_IN_FIFO_SHFT_MASK        (0x03u)
#define Shift_Reg_OUT_FIFO_SHFT_MASK       (0x05u)

#endif /* CY_SHIFTREG_Shift_Reg_H */

/* [] END OF FILE */
